var group__DRV__ENETPHY =
[
    [ "Generic PHY", "group__ENETPHY__GENERIC__PHY.html", null ],
    [ "TI DP83TG721 PHY", "group__ENETPHY__DP83TG721.html", "group__ENETPHY__DP83TG721" ],
    [ "EnetPhy_Version", "structEnetPhy__Version.html", [
      [ "oui", "structEnetPhy__Version.html#ae508bfdc1dffd61a5dc5ac04fd9c52a1", null ],
      [ "model", "structEnetPhy__Version.html#a6761be25acfe02923d1569b74ce1a25d", null ],
      [ "revision", "structEnetPhy__Version.html#ae4e18e89df0c29baae6eabcd87d89092", null ]
    ] ],
    [ "EnetPhy_LinkCfg", "structEnetPhy__LinkCfg.html", [
      [ "speed", "structEnetPhy__LinkCfg.html#afd1c050ab841ece3ab05bf62b5c0bb05", null ],
      [ "duplexity", "structEnetPhy__LinkCfg.html#a45eff7f3ecaa47161ee53137208feef3", null ]
    ] ],
    [ "EnetPhy_FsmTimeoutCfg", "structEnetPhy__FsmTimeoutCfg.html", [
      [ "findingStateTicks", "structEnetPhy__FsmTimeoutCfg.html#ae417fe4e396b00b96f14110e062f7a4c", null ],
      [ "resetWaitStateTicks", "structEnetPhy__FsmTimeoutCfg.html#aa4b7d9fc975206c1ba902250a2bdeb6a", null ],
      [ "resetWaitStateResidenceTicks", "structEnetPhy__FsmTimeoutCfg.html#a72e01f894bcad7c972591deee9628f3f", null ],
      [ "nwayStartStateTicks", "structEnetPhy__FsmTimeoutCfg.html#a0c5db9a07942ceb6797e1fa3cded7704", null ],
      [ "nwayWaitStateTicks", "structEnetPhy__FsmTimeoutCfg.html#a447c72930e2242bbc902fe71ce8b16f0", null ],
      [ "linkWaitStateTicks", "structEnetPhy__FsmTimeoutCfg.html#a760aa38c7add0c6daa092c9295bb4c4a", null ],
      [ "mdixTicks", "structEnetPhy__FsmTimeoutCfg.html#a48ac1448a476fb6888724cdadca9a064", null ]
    ] ],
    [ "EnetPhy_Cfg", "structEnetPhy__Cfg.html", [
      [ "phyGroup", "structEnetPhy__Cfg.html#a546102a2223d30e56cac6efc5b1f95fd", null ],
      [ "phyAddr", "structEnetPhy__Cfg.html#a8ddec0dca674469bd9ff7c9d4aeb6aba", null ],
      [ "nwayCaps", "structEnetPhy__Cfg.html#a326170d15fbd5660cd42f4058afca30b", null ],
      [ "mdixEn", "structEnetPhy__Cfg.html#af6ab0be3244688975ba5b1da98f9af54", null ],
      [ "isStrapped", "structEnetPhy__Cfg.html#aef3400ed350c5e78510e7ea6536b49ca", null ],
      [ "isIsolateStateReq", "structEnetPhy__Cfg.html#a13e073030c36adfcfb2578f3e6aab261", null ],
      [ "loopbackEn", "structEnetPhy__Cfg.html#a85bbc546f6fc38ede1e120db880eb27b", null ],
      [ "masterMode", "structEnetPhy__Cfg.html#ab3c6228827b13bc92c726e17f95db41e", null ],
      [ "extClkSource", "structEnetPhy__Cfg.html#a0fbd51a9e60e0b019a8d7c96f57464c7", null ],
      [ "skipExtendedCfg", "structEnetPhy__Cfg.html#afc86bd0c45ca1f4bd9fea2e8f37d2718", null ],
      [ "timeoutCfg", "structEnetPhy__Cfg.html#a2fec6f917edb406803098dc9fa8f0cfb", null ],
      [ "extendedCfg", "structEnetPhy__Cfg.html#a38afa8b7ff5c0444448080633a042762", null ],
      [ "extendedCfgSize", "structEnetPhy__Cfg.html#ae3048f34b725dbeec14676249aa3ddb7", null ]
    ] ],
    [ "EnetPhy_Mdio", "structEnetPhy__Mdio.html", [
      [ "isAlive", "structEnetPhy__Mdio.html#a1b052cda4dfe8479626db2962b638ef7", null ],
      [ "isLinked", "structEnetPhy__Mdio.html#a0e81c881f6411271e22200c953495679", null ],
      [ "readC22", "structEnetPhy__Mdio.html#a90a400312241d823da5e4e2180321743", null ],
      [ "writeC22", "structEnetPhy__Mdio.html#adf8aff6f641f4989d9e86b320644d3b0", null ],
      [ "readC45", "structEnetPhy__Mdio.html#ae5726adc4dc388d402253c819845c7b3", null ],
      [ "writeC45", "structEnetPhy__Mdio.html#a548a70b4056807f902199a0c0ed448cc", null ]
    ] ],
    [ "EnetPhy_State", "structEnetPhy__State.html", [
      [ "fsmState", "structEnetPhy__State.html#a7a1b87ae30afd4973a78214cc587ff5f", null ],
      [ "fsmStateChanged", "structEnetPhy__State.html#a32418e706ff4269251c83fb5334996d4", null ],
      [ "speed", "structEnetPhy__State.html#ace82b4fdcdd6dff56479412c9f6323d3", null ],
      [ "duplexity", "structEnetPhy__State.html#a23a7141dcb00f4ab2b794d79e391e783", null ],
      [ "timeout", "structEnetPhy__State.html#a39b049fcdfea083c6cdbcfa3cba7ace7", null ],
      [ "residenceTime", "structEnetPhy__State.html#abb3651617caed1c0ba14a76e728f3858", null ],
      [ "isNwayCapable", "structEnetPhy__State.html#a73d5167bee62e74f6eda098de55fa34e", null ],
      [ "enableNway", "structEnetPhy__State.html#a751e401d0f33865065206a3f52bf48ac", null ],
      [ "needsManualCfg", "structEnetPhy__State.html#a9fc95905371b64b198e447e4307c6819", null ],
      [ "needsNwayCfg", "structEnetPhy__State.html#a316597661ce5b376055576b0ba418f23", null ],
      [ "linkCaps", "structEnetPhy__State.html#a8ecd44bb2e8fd8298d0c5f4be2d8dc72", null ],
      [ "phyLinkCaps", "structEnetPhy__State.html#affcdf8170795dd5e245eb28f1f31ba3c", null ],
      [ "loopbackEn", "structEnetPhy__State.html#a7ccd637c31cbec932a42f981853c0ede", null ],
      [ "needsMdixSwitch", "structEnetPhy__State.html#ace7377bc77b85a643c240ff4d3dc652b", null ],
      [ "enableMdix", "structEnetPhy__State.html#a35921dba6384be1f92b8f4ea6be4310a", null ]
    ] ],
    [ "EnetPhy_Obj", "structEnetPhy__Obj.html", [
      [ "hMdio", "structEnetPhy__Obj.html#aba5c2a6c65120737b943ac37b418f850", null ],
      [ "phyCfg", "structEnetPhy__Obj.html#a75e7cedadf056e0b0512f286c051b413", null ],
      [ "mii", "structEnetPhy__Obj.html#acf0b022b5945134c1be9da34f3fc7f1f", null ],
      [ "macCaps", "structEnetPhy__Obj.html#aff6e978a83b3fb6cb928935e52148348", null ],
      [ "linkCfg", "structEnetPhy__Obj.html#af83aae079158fbe8b3afc28d081fb64c", null ],
      [ "timeoutCfg", "structEnetPhy__Obj.html#abbd01b6771dfd8fd1b87868e208bd672", null ],
      [ "state", "structEnetPhy__Obj.html#a2e67344e87b4670073386b9d4c879264", null ],
      [ "group", "structEnetPhy__Obj.html#a598b95b4f8f6e5d6cb9d09fdddedf808", null ],
      [ "addr", "structEnetPhy__Obj.html#a3cb346e8055e88a8bad2abcb6e529a3a", null ],
      [ "reqLinkCaps", "structEnetPhy__Obj.html#ad277b7ca1134d1809919408a5cfaf413", null ],
      [ "hDrvIf", "structEnetPhy__Obj.html#a850453b51829db99fd0ce5b7eb893e0e", null ],
      [ "magic", "structEnetPhy__Obj.html#ab09f1f4d15d40dae95f9246946646308", null ],
      [ "mdioArgs", "structEnetPhy__Obj.html#a85e4d163e1873aafc8e19073fa494590", null ],
      [ "priv", "structEnetPhy__Obj.html#a7be549959efd1b2ac45387c2dea1d76f", null ]
    ] ],
    [ "ENETPHY_IS_ADDR_VALID", "group__DRV__ENETPHY.html#gad646043be1e207b7fb6ba1bae5371c4a", null ],
    [ "ENETPHY_BIT", "group__DRV__ENETPHY.html#ga42a23019279db985de2fd7bd5c4a6b32", null ],
    [ "ENETPHY_IS_BIT_SET", "group__DRV__ENETPHY.html#ga2aeb23504dcc8f2646a7db5ca8256a40", null ],
    [ "ENETPHY_ARRAYSIZE", "group__DRV__ENETPHY.html#ga86398d7f69319c95cb3d297100f8ee4a", null ],
    [ "ENETPHY_SOK", "group__DRV__ENETPHY.html#gaa26358c57842ec343aceb6f7fd022b78", null ],
    [ "ENETPHY_EFAIL", "group__DRV__ENETPHY.html#gaf89f56d59cea6e6a8af75f9ea251bb65", null ],
    [ "ENETPHY_EBADARGS", "group__DRV__ENETPHY.html#gaf9eab25780b1d3fb05f2ede24aa98dd8", null ],
    [ "ENETPHY_EINVALIDPARAMS", "group__DRV__ENETPHY.html#ga3231c4e8badc9f2b6a0c877548776a6c", null ],
    [ "ENETPHY_ETIMEOUT", "group__DRV__ENETPHY.html#ga079f24ed8598827f191e0edcae4f0ed2", null ],
    [ "ENETPHY_EALLOC", "group__DRV__ENETPHY.html#ga3f04871b7819dfdd4c751d6f3da72eb8", null ],
    [ "ENETPHY_EPERM", "group__DRV__ENETPHY.html#gaf000eee87b30b560efb240b563aba84a", null ],
    [ "ENETPHY_ENOTSUPPORTED", "group__DRV__ENETPHY.html#gab2ddd9c4da3de62bd1ec4f91c1423c04", null ],
    [ "ENETPHY_EUNAVAILABLE", "group__DRV__ENETPHY.html#gaa9baf8e858b6b7be16eaa576f2b96f6a", null ],
    [ "ENETPHY_LINK_CAP_HD10", "group__DRV__ENETPHY.html#ga3dc4194bba86e7f9a793ebdf9d963f96", null ],
    [ "ENETPHY_LINK_CAP_FD10", "group__DRV__ENETPHY.html#ga8888e695def8844c5b265fdfe0e98376", null ],
    [ "ENETPHY_LINK_CAP_HD100", "group__DRV__ENETPHY.html#ga0506e3cd213458b8b9211ac04bc0eeca", null ],
    [ "ENETPHY_LINK_CAP_FD100", "group__DRV__ENETPHY.html#gadf5e52bd2dc0d319c1b364851a52d4d6", null ],
    [ "ENETPHY_LINK_CAP_HD1000", "group__DRV__ENETPHY.html#gaf53b382721f6945f0e346d6a47228a0a", null ],
    [ "ENETPHY_LINK_CAP_FD1000", "group__DRV__ENETPHY.html#ga750cceb0d3fdfe1c23081835a05d3991", null ],
    [ "ENETPHY_LINK_CAP_10", "group__DRV__ENETPHY.html#gafc67189b47460ed78ab4b2d8048874d0", null ],
    [ "ENETPHY_LINK_CAP_100", "group__DRV__ENETPHY.html#ga040890f80a82eedfe1e76bc46a776960", null ],
    [ "ENETPHY_LINK_CAP_1000", "group__DRV__ENETPHY.html#ga173e433858b5ed273d8c1147da61c14f", null ],
    [ "ENETPHY_LINK_CAP_ALL", "group__DRV__ENETPHY.html#ga5de918539d53d1fce1bb92517b43e3b4", null ],
    [ "ENETPHY_EXTENDED_CFG_SIZE_MAX", "group__DRV__ENETPHY.html#ga171c1b2ae62c76b6aae0c1fa8a16d35f", null ],
    [ "ENETPHY_FSM_TICK_PERIOD_MS", "group__DRV__ENETPHY.html#ga1bd62ca7a9dd3a10badc993f17e6e823", null ],
    [ "ENETPHY_INVALID_PHYADDR", "group__DRV__ENETPHY.html#gaac99db2dbc6b1607f75384f3aa15fdba", null ],
    [ "ENETPHY_TIMEOUT_WAIT_FOREVER", "group__DRV__ENETPHY.html#gab83ed97712deb9e0c9fbb57352798bd6", null ],
    [ "ENETPHY_TIMEOUT_NO_WAIT", "group__DRV__ENETPHY.html#ga9bc19f2b33c4f1e9bdd6f7cfae87f6f8", null ],
    [ "Mdio_Obj", "group__DRV__ENETPHY.html#gaa1d96cf32f75f046e6c14d4296ba23ab", null ],
    [ "EnetPhy_MdioHandle", "group__DRV__ENETPHY.html#ga716230b8d453cbadf076c6d2e6db6468", null ],
    [ "EnetPhy_Handle", "group__DRV__ENETPHY.html#ga321b990b312722b35a86cf9d09be4e48", null ],
    [ "EnetPhy_Magic", "group__DRV__ENETPHY.html#gaf3c210740d0f86ebaee58dafeaf00ae7", [
      [ "ENETPHY_MAGIC", "group__DRV__ENETPHY.html#ggaf3c210740d0f86ebaee58dafeaf00ae7ae49dede0f79dbe62dbc48509621c3d27", null ],
      [ "ENETPHY_NO_MAGIC", "group__DRV__ENETPHY.html#ggaf3c210740d0f86ebaee58dafeaf00ae7a02f5a5b3b648672eb701836b70dad407", null ]
    ] ],
    [ "EnetPhy_Mii", "group__DRV__ENETPHY.html#ga69b0f5527a705ae47cac5b53a1f8f204", [
      [ "ENETPHY_MAC_MII_MII", "group__DRV__ENETPHY.html#gga69b0f5527a705ae47cac5b53a1f8f204a7041dbfbec7982d650b1e963d8010e5a", null ],
      [ "ENETPHY_MAC_MII_RMII", "group__DRV__ENETPHY.html#gga69b0f5527a705ae47cac5b53a1f8f204a1fc6ae7f29c106eeabe10935df704cec", null ],
      [ "ENETPHY_MAC_MII_GMII", "group__DRV__ENETPHY.html#gga69b0f5527a705ae47cac5b53a1f8f204abe42da3a084b8aadf25ce696b504201b", null ],
      [ "ENETPHY_MAC_MII_RGMII", "group__DRV__ENETPHY.html#gga69b0f5527a705ae47cac5b53a1f8f204aa043a901dc6f0aee5ad6d206be068de0", null ],
      [ "ENETPHY_MAC_MII_SGMII", "group__DRV__ENETPHY.html#gga69b0f5527a705ae47cac5b53a1f8f204a2aa72d1ec1b5c11c050f0e0cef447800", null ],
      [ "ENETPHY_MAC_MII_QSGMII", "group__DRV__ENETPHY.html#gga69b0f5527a705ae47cac5b53a1f8f204a484c0a25d1102b746a5a2bae9476384b", null ]
    ] ],
    [ "EnetPhy_Speed", "group__DRV__ENETPHY.html#gaedbe537f2ee305e9f6abb6b274eb905d", [
      [ "ENETPHY_SPEED_10MBIT", "group__DRV__ENETPHY.html#ggaedbe537f2ee305e9f6abb6b274eb905da3f7f331215fb26a18b5be0bc604574ff", null ],
      [ "ENETPHY_SPEED_100MBIT", "group__DRV__ENETPHY.html#ggaedbe537f2ee305e9f6abb6b274eb905dab38d5db7b53391d7c6753d48f0c34c6c", null ],
      [ "ENETPHY_SPEED_1GBIT", "group__DRV__ENETPHY.html#ggaedbe537f2ee305e9f6abb6b274eb905da0e1faf2d75efd02a35fbcff360fc8c40", null ],
      [ "ENETPHY_SPEED_AUTO", "group__DRV__ENETPHY.html#ggaedbe537f2ee305e9f6abb6b274eb905da7d68bab5bde21105cc9d0bc21731a48f", null ]
    ] ],
    [ "EnetPhy_Duplexity", "group__DRV__ENETPHY.html#gac4fd32f7471b8a9061e05a99ab4ad85e", [
      [ "ENETPHY_DUPLEX_HALF", "group__DRV__ENETPHY.html#ggac4fd32f7471b8a9061e05a99ab4ad85ea25e7ec761dc6f57781b972d1cbb4ec0e", null ],
      [ "ENETPHY_DUPLEX_FULL", "group__DRV__ENETPHY.html#ggac4fd32f7471b8a9061e05a99ab4ad85eafb6b4e6a2590776bf1e10ae98a8d00d6", null ],
      [ "ENETPHY_DUPLEX_AUTO", "group__DRV__ENETPHY.html#ggac4fd32f7471b8a9061e05a99ab4ad85ea837800564e32e45e5d6d40dbddce4fb3", null ]
    ] ],
    [ "EnetPhy_LinkStatus", "group__DRV__ENETPHY.html#ga4b2bc2f18084d53342a5adfb3003af7d", [
      [ "ENETPHY_GOT_LINK", "group__DRV__ENETPHY.html#gga4b2bc2f18084d53342a5adfb3003af7da95580471da445a026be4552996abe6a0", null ],
      [ "ENETPHY_LINK_UP", "group__DRV__ENETPHY.html#gga4b2bc2f18084d53342a5adfb3003af7dab5f502f51126a42443b0d0c950d8b71b", null ],
      [ "ENETPHY_LOST_LINK", "group__DRV__ENETPHY.html#gga4b2bc2f18084d53342a5adfb3003af7da4489066892eb518941bab62996984e2a", null ],
      [ "ENETPHY_LINK_DOWN", "group__DRV__ENETPHY.html#gga4b2bc2f18084d53342a5adfb3003af7dacd77d3dd42f61f1fac40d48ac1284757", null ]
    ] ],
    [ "EnetPhy_FsmState", "group__DRV__ENETPHY.html#gae587cb11639bc55116a9b434ed06694c", [
      [ "ENETPHY_FSM_STATE_INIT", "group__DRV__ENETPHY.html#ggae587cb11639bc55116a9b434ed06694ca0649db1ea36711dbd002b98f1c062c2c", null ],
      [ "ENETPHY_FSM_STATE_FINDING", "group__DRV__ENETPHY.html#ggae587cb11639bc55116a9b434ed06694ca1a5797b0c893501222c97a1f1186694c", null ],
      [ "ENETPHY_FSM_STATE_RESET_WAIT", "group__DRV__ENETPHY.html#ggae587cb11639bc55116a9b434ed06694ca3c02086aee4878a0f9aaa98187a22edc", null ],
      [ "ENETPHY_FSM_STATE_ENABLE", "group__DRV__ENETPHY.html#ggae587cb11639bc55116a9b434ed06694ca03a9d2637bd6692dc1c20710fb552735", null ],
      [ "ENETPHY_FSM_STATE_FOUND", "group__DRV__ENETPHY.html#ggae587cb11639bc55116a9b434ed06694cad2d918e306422e2339b5c3bec4dfbdea", null ],
      [ "ENETPHY_FSM_STATE_NWAY_START", "group__DRV__ENETPHY.html#ggae587cb11639bc55116a9b434ed06694ca654bd075c91c118eaa08ec4ce7313c86", null ],
      [ "ENETPHY_FSM_STATE_NWAY_WAIT", "group__DRV__ENETPHY.html#ggae587cb11639bc55116a9b434ed06694caafabde2c05566301bd24b77edb6a5abc", null ],
      [ "ENETPHY_FSM_STATE_LINK_WAIT", "group__DRV__ENETPHY.html#ggae587cb11639bc55116a9b434ed06694ca86db66aa51421cb96c96da03aa017457", null ],
      [ "ENETPHY_FSM_STATE_LINKED", "group__DRV__ENETPHY.html#ggae587cb11639bc55116a9b434ed06694cac9559b0574ad03dbed3a3982396d897c", null ],
      [ "ENETPHY_FSM_STATE_LOOPBACK", "group__DRV__ENETPHY.html#ggae587cb11639bc55116a9b434ed06694ca4c8c9948975b9279ee6bd7b0dbda3722", null ],
      [ "ENETPHY_FSM_STATE_ISOLATE", "group__DRV__ENETPHY.html#ggae587cb11639bc55116a9b434ed06694caef3b0b24050475f1042fa95e6940121b", null ]
    ] ],
    [ "EnetPhy_initCfg", "group__DRV__ENETPHY.html#gaff5006a4c712434d31f67b3d5d4b3bf9", null ],
    [ "EnetPhy_setExtendedCfg", "group__DRV__ENETPHY.html#ga5f7008641bf565765c557f55756937a4", null ],
    [ "EnetPhy_open", "group__DRV__ENETPHY.html#ga1d8cebac9cf8a645b504894220106215", null ],
    [ "EnetPhy_close", "group__DRV__ENETPHY.html#ga1d69a2547cc8cb17c9ccd397ac164378", null ],
    [ "EnetPhy_tick", "group__DRV__ENETPHY.html#ga82babbc2e9c65ac5dc541c6fc8e33ca3", null ],
    [ "EnetPhy_getId", "group__DRV__ENETPHY.html#ga1f5f88ec72a5d6b371a7954131f791fb", null ],
    [ "EnetPhy_isAlive", "group__DRV__ENETPHY.html#ga44228766624b60da80c50ec2525107e2", null ],
    [ "EnetPhy_isLinked", "group__DRV__ENETPHY.html#gae8c9df0eace5f8b6b809176a0c420cda", null ],
    [ "EnetPhy_getLinkCfg", "group__DRV__ENETPHY.html#ga67859143637d0b09b8d3249774c1c002", null ],
    [ "EnetPhy_getLinkStatus", "group__DRV__ENETPHY.html#ga6c43a066e16bc7f2aa317376c4ec87fd", null ],
    [ "EnetPhy_readReg", "group__DRV__ENETPHY.html#ga91edf30111d6ae795012514542e285d8", null ],
    [ "EnetPhy_writeReg", "group__DRV__ENETPHY.html#ga5b7e4026319c8138985fe4801f26bc43", null ],
    [ "EnetPhy_rmwReg", "group__DRV__ENETPHY.html#ga1a8b1d84f67084d34edd9b42ceb05965", null ],
    [ "EnetPhy_readExtReg", "group__DRV__ENETPHY.html#gabdd66d8f016935402e364379ff31bcf8", null ],
    [ "EnetPhy_writeExtReg", "group__DRV__ENETPHY.html#ga38c339c1c248304d653398e7a0a866f0", null ],
    [ "EnetPhy_rmwExtReg", "group__DRV__ENETPHY.html#gaf95e72866cee60c328592b4fc3a95943", null ],
    [ "EnetPhy_readC45Reg", "group__DRV__ENETPHY.html#gaffc3fd5abf62e9d2b0ff41869b2622ec", null ],
    [ "EnetPhy_writeC45Reg", "group__DRV__ENETPHY.html#ga2f5294c3ffcd261efce2573c32038cbd", null ],
    [ "EnetPhy_rmwC45Reg", "group__DRV__ENETPHY.html#ga0785780a87174ef9fabff8b6a49a1cb2", null ],
    [ "EnetPhy_printRegs", "group__DRV__ENETPHY.html#ga86d2852ee8d820639c56aa26104965fc", null ],
    [ "EnetPhy_adjPtpFreq", "group__DRV__ENETPHY.html#ga1f2bbacde0de1fefe7dbf5e844324851", null ],
    [ "EnetPhy_adjPtpPhase", "group__DRV__ENETPHY.html#ga6f49b6a8f4260ed3817279c73fcdd53e", null ],
    [ "EnetPhy_getPtpTime", "group__DRV__ENETPHY.html#ga3d01b2f12415b08d414b11d17582efc0", null ],
    [ "EnetPhy_setPtpTime", "group__DRV__ENETPHY.html#gaf8bb9ad3d5840e91bfe2bb840c8ee034", null ],
    [ "EnetPhy_getPtpTxTime", "group__DRV__ENETPHY.html#gaf8cfa0f6f53343bff002f7d8e75f3fe4", null ],
    [ "EnetPhy_getPtpRxTime", "group__DRV__ENETPHY.html#gaaab7c58d5123053eeb47966f8859fe6b", null ],
    [ "EnetPhy_waitPtpTxTime", "group__DRV__ENETPHY.html#ga8e87a0bdd1d1939ab335cc53f5729c3d", null ],
    [ "EnetPhy_procStatusFrame", "group__DRV__ENETPHY.html#gab8456a1df856f905983dde40b2a95d99", null ],
    [ "EnetPhy_getStatusFrameEthHeader", "group__DRV__ENETPHY.html#gad861d859a82140f5c570acb71145f602", null ],
    [ "EnetPhy_enablePtp", "group__DRV__ENETPHY.html#gaf5d0a5d67fe73b693efcfa6062518b9d", null ],
    [ "EnetPhy_tickDriver", "group__DRV__ENETPHY.html#ga62ccd584b1844929926fb9554c95683d", null ],
    [ "EnetPhy_enableEventCapture", "group__DRV__ENETPHY.html#ga0dc85abb0de79855f3f8e3b26f48ffb6", null ],
    [ "EnetPhy_enableTriggerOutput", "group__DRV__ENETPHY.html#ga65171003450b027831a898c7c2dfe693", null ],
    [ "EnetPhy_getEventTs", "group__DRV__ENETPHY.html#ga6a5b68a158188d891346fb6b74096b31", null ],
    [ "EnetPhy_configMediaClock", "group__DRV__ENETPHY.html#gab3ff4a61a3baece654a738afa369cd4a", null ],
    [ "EnetPhy_nudgeCodecClock", "group__DRV__ENETPHY.html#ga9535e9ca77ebdba36a29c48ee1481bf5", null ]
];